import { ElementRef, OnDestroy, AfterViewInit, NgZone } from '@angular/core';
import { NgForm } from '@angular/forms';
import 'rxjs/add/observable/forkJoin';
import 'rxjs/add/observable/interval';
import 'rxjs/add/operator/mapTo';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/first';
import 'rxjs/add/operator/skipWhile';
import 'rxjs/add/observable/of';
import 'rxjs/add/observable/timer';
import { FormHelperConfig } from './form-helper-config';
/**
 * --------------------------------------------------------------------------------------------------------
 * data-* api
 *  1)debounce-time：远程验证时使用，指定请求抖动时间。单位ms，使用方表单域/表单组
 *  2)scroll-proxy：设置表单域/表单组滚动代理
 *                  语法：^ -> 父节点，~ -> 前一个兄弟节点，+ -> 后一个兄弟节点。可以任意组合
 *                  示例：^^^，^2，~3^4+2
 *
 * --------------------------------------------------------------------------------------------------------
 * validators
 *  1)trimmedRequired
 *
 * --------------------------------------------------------------------------------------------------------
 * angular表单存在的bug
 *  1)bug：表单域name使用模板表达式生成(如：name="name-{{attr}}")，则最终的html标签中name属性会丢失
 *    fix：同时使用name和[attr.name]。使用本插件不需要[attr.name]
 *  2)bug：当使用ngFor迭代表单域，且name使用数组下标(如：name-{{i}})，此时若动态新增/删除表单域，会造成表单域数量混乱
 *    fix：这种情况下请保证name唯一，且必须使用trackBy返回唯一标识，推荐使用uuid等工具(如：name-{{uuid}})
 */
export declare class FormHelperDirective implements AfterViewInit, OnDestroy {
    private ngForm;
    private form;
    private zone;
    formHelper: FormHelperConfig;
    keydown(event: KeyboardEvent): void;
    resize(): void;
    submitted: boolean;
    private _config;
    private mutationObserver;
    private $form;
    private destroys;
    private readonly submitHandlerKey;
    private readonly errorHandlerKey;
    private static submitHandlerMap;
    private static errorHandlerMap;
    constructor(ngForm: NgForm, form: ElementRef, zone: NgZone);
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    reposition(ele?: string): void;
    private triggerReposition(name);
    static registerSubmitHandler(name: string, handler: Function): void;
    static registerErrorHandler(name: string, handler: Function): void;
    private bindSubmitButtons();
    private bindErrorHandlers(controls?);
    private bindErrorHandler(control);
    private listenStatusChanges(control, $field);
    private submit(submitHandler?);
    private validateControls(controls?);
    private getPendingControls(controls?);
    private scrollToTopError();
    private findContext();
    private calcMinOffsetTop(controls?);
    private findClosestVisibleItem(control);
    private reset();
}
